@@ -1,13 +1,14 @@
 from dataclasses import dataclass
 from tesla.exceptions import DatabaseException
 from tesla.modal import Model
-import bcrypt
+
 
 
 
 class UserBaseModal(Model):
  
     def save(self):
+        
         # check if no User with this username
         # exis
         
@@ -17,6 +18,8 @@ class UserBaseModal(Model):
             raise DatabaseException('User with this username already exists')
         # hashes the password
         elif existing_user == None:
-            password = bcrypt.hashpw(self.password.encode(), bcrypt.gensalt(prefix=b'2a')).decode()
+            from argon2 import PasswordHasher
+            ph = PasswordHasher()
+            password = hash = ph.hash(self.password)
             self.password = password
         return super().save()
\ No newline at end of file
